@@ -1,9 +1,11 @@
 #' Contract graph vertices based on brain lobe and hemisphere
 #'
-#' This function creates a new graph after merging multiple vertices based on
-#' brain lobe and hemisphere membership. The new vertex size is equal to the
-#' number of vertices in each lobe. The x- and y- coordinates of the new
-#' vertices are equal to the mean of the lobe vertices of the original graph.
+#' Create a new graph after merging multiple vertices based on brain \emph{lobe}
+#' and \emph{hemisphere} membership.
+#'
+#' The vertex size of the resultant graph is equal to the number of vertices in
+#' each lobe (in the input graph). The x- and y- coordinates of the new vertices
+#' are equal to the mean coordinates of the lobe vertices of the original graph.
 #' The new edge weight is equal to the number of inter-lobular connections of
 #' the original graph.
 #'
@@ -31,7 +33,8 @@ contract_brainGraph <- function(g) {
   vcols <- rep(vcols, 2)
   V(g.sub)$color <- vcols
   V(g.sub)$lobe <- rep(sort(unique(V(g)$lobe)), 2)
-  E(g.sub)$color.lobe <- set_edge_color(g.sub, V(g.sub)$lobe)
+  g.sub <- set_edge_color(g.sub, 'color.lobe', V(g.sub)$lobe)
 
+  class(g.sub) <- c('brainGraph', class(g.sub))
   return(g.sub)
 }
